==============================================
Welcome to Cytoflow's developer documentation!
==============================================

*******
I want to use Cytoflow's modules in my own cytometry analysis
*******

Great!  May I recommend you start with some example Jupyter notebooks.
They provide a good introduction to both basic modules and some of
Cytoflow's more advanced features.

* `Basic flow cytometry analysis <https://github.com/bpteague/cytoflow/blob/master/docs/examples-basic/Basic%20Cytometry.ipynb>`_
* `An small-molecule induction curve with yeast <https://github.com/bpteague/cytoflow/blob/master/docs/examples-basic/Yeast%20Dose%20Reponse.ipynb>`_
* `Data-driven gating with gaussian mixture models <https://github.com/bpteague/cytoflow/blob/master/docs/examples-basic/Machine%20Learning.ipynb>`_
* `Reproduced some analysis from a published paper <https://github.com/bpteague/cytoflow-examples/blob/master/kiani/Kiani%20Nature%20Methods%202014.ipynb>`_
* `Calibrated flow cytometry in MEFLs <https://github.com/bpteague/cytoflow-examples/blob/master/tasbe/TASBE%20Workflow.ipynb>`_

If you decide you want to have a go, see the 
:ref:`installation notes <install>`.
Quick hint: if you have a working Python v2.7 development environment, say
``pip install cytoflow`` to install the latest package from the 
`Python Package Index <https://pypi.python.org/pypi>`_.

For more details of these modules, you're likely to want to see the 
:ref:`module documents <modindex>`

****
I want to help develop Cytoflow.
****

Hooray!  Have a look at the :ref:`install documentation <hacking>` for how to
get the source code installed.  Then, have a look at the 
:ref:`design docs <design>` and (more or less up-to-date) :ref:`TODO <todo>`.
Finally, subscribe to 
`the cytoflow-dev mailing list <https://groups.google.com/forum/#!forum/cytoflow-dev>`_ for updates, discussion, etc.

****
Contents:
****

.. toctree::
   :maxdepth: 2
   
   INSTALL
   design
   TODO
   RELEASE
   
:doc:`Module reference <modules>`

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

